@@ -20,7 +20,7 @@ REPO_MAINTAINERS = [
 ]
 
 # Package version in the format (major, minor, release)
-PACKAGE_VERSION_TUPLE = (0, 9, 5)
+PACKAGE_VERSION_TUPLE = (0, 10, 3)
 
 # Short description of the package
 PACKAGE_SHORT_DESCRIPTION = "Nick DeRobertis' CV Data and pyexlatex Build"
@@ -62,7 +62,7 @@ PACKAGE_INSTALL_REQUIRES = [
     # e.g.
     # 'package',
     # 'otherpackage>=1,<2'
-    'pl-builder',
+    'pl-builder<1',
     'pyyaml',
     'project-report',
     'weakreflist',
