@@ -1,14 +1,19 @@
 from abc import ABC, abstractmethod
-from typing import Dict, TYPE_CHECKING
+from typing import Dict, TYPE_CHECKING, Protocol
+
 if TYPE_CHECKING:
     from derobertis_cv.models.skill_experience import SkillExperience
 
 
+class ExperienceAttributes(Protocol):
+    hours: float
+
+
 class SkillExperienceScale(ABC):
 
     @classmethod
     @abstractmethod
-    def experience_to_level(cls, exp: 'SkillExperience') -> int:
+    def experience_to_level(cls, exp: ExperienceAttributes) -> int:
         ...
 
     @classmethod
@@ -26,7 +31,7 @@ class HoursExperienceScale(SkillExperienceScale):
     }
 
     @classmethod
-    def experience_to_level(cls, exp: 'SkillExperience') -> int:
+    def experience_to_level(cls, exp: ExperienceAttributes) -> int:
         hours = exp.hours
         level = 0
         for level, cutoff in cls.cutoffs.items():
