@@ -128,8 +128,15 @@ class SpecificApplicationFocus(str, Enum):
             model.minimum_skill_priority = 4
             return model
 
+        # TODO [#52]: find better location for general cv modifier funcs
+        def tech_company_resume(model: 'CVModel') -> 'CVModel':
+            model.minimum_skill_priority = 5
+            model.font_scale = 0.9
+            model.line_spacing = 1.025
+            return model
+
         func_map: Dict['SpecificApplicationFocus', Callable[['CVModel'], 'CVModel']] = {
-            cls.TECH_COMPANY: set_skill_priority_to_4,
+            cls.TECH_COMPANY: tech_company_resume,
             cls.DATA_SCIENCE: set_skill_priority_to_4,
             cls.ECONOMIST: set_skill_priority_to_4,
         }
