@@ -97,6 +97,8 @@ class CVModel:
     minimum_skill_priority: int = 1
     application_focus: Optional[ApplicationFocus] = None
     specific_application_focus: Optional[SpecificApplicationFocus] = None
+    custom_contact_lines_func: Optional[Callable[[bool], PyexlatexItems]] = None
+    include_footer: bool = True
 
     def __post_init__(self):
         if self.software_project_order is None and self.included_software_projects is not None:
@@ -115,13 +117,19 @@ class CVModel:
             return self.application_focus
         return None
 
+    @property
+    def contact_lines_func(self) -> Callable[[bool], PyexlatexItems]:
+        if self.custom_contact_lines_func is not None:
+            return self.custom_contact_lines_func
+        return get_cv_contact_lines
+
     def to_pyexlatex_resume(self) -> lr.Resume:
         contents = get_cv_contents(self)
         resume = lr.Resume(
             contents,
-            contact_lines=get_cv_contact_lines(include_website=self.include_website_in_contact_lines),
+            contact_lines=self.contact_lines_func(self.include_website_in_contact_lines),
             packages=get_cv_packages(font_scale=self.font_scale, line_spacing=self.line_spacing),
-            pre_env_contents=get_cv_pre_env_contents(font_scale=self.font_scale),
+            pre_env_contents=get_cv_pre_env_contents(font_scale=self.font_scale, include_footer=self.include_footer),
             authors=['Nick DeRobertis'],
         )
         return resume
@@ -314,21 +322,24 @@ def get_cv_contents(model: CVModel, include_self_image: bool = True) -> List[Ite
     return selected_contents
 
 
-def get_cv_pre_env_contents(font_scale: Optional[float] = None) -> PyexlatexItems:
-    diamond = pl.Raw(r' $\diamond$ ')
-    footer_parts = [NAME, EMAIL, PHONE, STYLED_SITE]
-    footer = str(diamond).join([str(p) for p in footer_parts])
-
+def get_cv_pre_env_contents(font_scale: Optional[float] = None, include_footer: bool = True) -> PyexlatexItems:
     pe_contents: List[PyexlatexItem] = [
         pl.Raw(r'\definecolor{darkblue}{RGB}{50,82,209}'),
         PageStyle("fancyplain"),
         remove_header,
-        pl.LeftFooter(footer),
         pl.CenterFooter(''),
-        pl.RightFooter(pl.ThisPageNumber()),
-        pl.FooterLine()
     ]
 
+    if include_footer:
+        diamond = pl.Raw(r' $\diamond$ ')
+        footer_parts = [NAME, EMAIL, PHONE, STYLED_SITE]
+        footer = str(diamond).join([str(p) for p in footer_parts])
+        pe_contents.extend([
+            pl.LeftFooter(footer),
+            pl.RightFooter(pl.ThisPageNumber()),
+            pl.FooterLine()
+        ])
+
     if font_scale is not None:
         font_str = (
                 r'\setmainfont{Latin Modern Roman}[Scale =' +
@@ -507,7 +518,8 @@ CV_MODELS: Dict[CVTypes, CVModel] = {
             'CSS': 'Programming',
             'LaTeX': 'Programming',
             'HTML': 'Programming',
-        }
+        },
+        include_footer=False,
     )
 }
 for specific_focus in SpecificApplicationFocus.get_specific_resume_types():
@@ -536,5 +548,25 @@ def build_cvs(cv_models: Sequence[CVModel] = CV_MODELS_TUP, outfolder: str = DOC
         mod.output(outfolder)
 
 
+def build_cv_by_cv_type(cv_type: CVTypes, cv_models: Optional[Dict[CVTypes, CVModel]] = None, outfolder: str = DOCUMENTS_BUILD_PATH):
+    if cv_models is None:
+        cv_models = CV_MODELS
+
+    try:
+        mod = cv_models[cv_type]
+    except KeyError:
+        raise ValueError(f'no such cv type {cv_type}. Pass one of {[t.value for t in CVTypes]}')
+
+    print(f'Building {mod.file_name}')
+    mod.output(outfolder)
+
+
 if __name__ == '__main__':
-    build_cvs()
\ No newline at end of file
+    import argparse
+    parser = argparse.ArgumentParser()
+    parser.add_argument('-t', '--type', required=False, default=None, type=str, help="CVType of CV to build")
+    args = parser.parse_args()
+    if args.type is not None:
+        build_cv_by_cv_type(args.type)
+    else:
+        build_cvs()
\ No newline at end of file
