@@ -78,11 +78,59 @@ def get_professional_jobs(
             'Tutor',
             'Gainesville, FL',
             datetime.datetime(2017, 9, 1),
-            end_date=None,
+            end_date=datetime.datetime(2021, 4, 12),
             company_short_name='PT',
             short_job_title='Tutor',
             hours_per_week=3,
-        )
+        ),
+        EmploymentModel(
+            JobIDs.CLAIMFOUND_CTO.value,
+            [
+                'Created the business that ultimately grew to 15 employees, raised $1.75M, '
+                'and was acquired by Carbon Health Technologies, with only one co-founder',
+                'Manage up to 10 software developers, providing technical guidance and tracking progress, using '
+                'a custom management system designed based on agile practices',
+                'Architect a web application with a Python Flask back-end API and a TypeScript Angular front-end '
+                'to assist individuals in claiming lost money',
+                'Design and implement data pipelines which clean and aggregate state unclaimed property data '
+                'into a 3NF schema in a PosgreSQL database hosted in AWS RDS',
+                'Developed the full-stack prototype of the application and deployed it using Docker Swarm on '
+                'AWS EC2 instances',
+                'Secure, monitor, and manage the application by developing encryption, rate limiting, active monitoring '
+                'services, user analytics, and operator interfaces',
+                'Optimize consumer funnel by analyzing conversions in an A/B testing framework',
+                'Automate testing, data pipelines, and deployment using Python and Bash scripts, '
+                'AWS CLI, and Gitlab CI/CD',
+                'Strategize about product development to improve user experience (UX) and monetization while appeasing '
+                'regulatory concerns',
+                'Assess and refine product-market fit by developing detailed financial models and updating them '
+                'with information learned from user analytics, user feedback, and regulatory response',
+            ],
+            'Claimfound, Inc.',
+            'Co-Founder and Chief Technology Officer',
+            'Gainesville, FL',
+            datetime.datetime(2016, 8, 15),
+            hours_per_week=40,
+        ),
+        EmploymentModel(
+            JobIDs.CARBON_HEALTH.value,
+            [
+                "Collaborate with product, design, data science, and other engineers to release features that "
+                "improve the productivity of clinicians and support staff",
+                "Architect and execute large projects to improve the Scala monolith, "
+                "Kotlin microservices, and React Native mobile and web applications",
+                "Optimize performance of existing product features by implementing caching, "
+                "query optimization, reducing component renders, and re-architecting with GraphQL "
+                "to minimize data transfer",
+                "Refine organizational engineering practices by contributing to discussions and documentation",
+                "Assist in training and hiring of new engineers"
+            ],
+            'Carbon Health Technologies',
+            'Senior Software Engineer',
+            'San Francisco, CA',
+            datetime.datetime(2021, 4, 12),
+            hours_per_week=40,
+        ),
     ]
     if include_private:
         from private_cv.jobs import get_professional_jobs as get_private_jobs
