@@ -1,6 +1,6 @@
 import operator
 from copy import deepcopy
-from typing import Sequence, Optional, List, Dict, cast, Set, Union
+from typing import Sequence, Optional, List, Dict, cast, Set, Union, Final
 
 from pyexlatex.logic.format.and_join import join_with_commas_and_and_output_list
 
@@ -8,9 +8,14 @@ from derobertis_cv.models.skill import SkillModel
 from derobertis_cv.models.cased import first_word_untouched_rest_capitalized, \
     first_word_untouched_rest_lower, first_word_untouched_rest_title
 from derobertis_cv.models.skill_experience import SkillExperience
+from derobertis_cv.models.skill_experiences import SkillExperiences
 from derobertis_cv.pldata.cover_letters.models import SkillFocusPriority, SpecificApplicationFocus, ApplicationFocus
 
 
+CARBON_BEGIN_DATE: Final[str] = "4/12/2021"
+GRAPHQL_BEGIN_DATE: Final[str] = "12/20/2021"
+
+
 def _recursive_sort_skills(skills: List[SkillModel], **sort_kwargs):
     skills.sort(**sort_kwargs)
     for skill in skills:
@@ -37,26 +42,38 @@ TEACHING_SKILL = SkillModel(
 ATTENTION_TO_DETAIL_SKILL = SkillModel('attention to detail', 5, parents=(SOFT_SKILLS,))
 SOFTWARE_ARCHITECTURE_SKILL = SkillModel(
     'software architecture', 4, primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('9/1/2012', hours_per_week=4),
+    experience=SkillExperiences([
+        SkillExperience('9/1/2012', hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=8),
+    ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
 )
 OS_SKILL = SkillModel('operating systems', 3, primary_category=OTHER, priority=SkillFocusPriority(1))
 HARDWARE_SKILL = SkillModel('computer hardware', 3, primary_category=OTHER, priority=SkillFocusPriority(1))
 SOFTWARE_DEVELOPMENT_SKILL = SkillModel(
     'software development', 5, parents=(PROGRAMMING_SKILL,),
-    experience=SkillExperience('9/1/2012', hours_per_week=20),
+    experience=SkillExperiences([
+        SkillExperience('9/1/2012', hours_per_week=20, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=30),
+    ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
 )
 FRONTEND_SKILL = SkillModel(
     'Front-end Development', 4, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL),
     primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('8/1/2016', hours_per_week=5),
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=10),
+    ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 BACKEND_SKILL = SkillModel(
     'Back-end Development', 5, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL),
     primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('9/1/2012', hours_per_week=10),
+    experience=SkillExperiences([
+        SkillExperience('9/1/2012', hours_per_week=10, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=20),
+    ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 CLI_SKILL = SkillModel(
@@ -87,16 +104,27 @@ REMOTE_DEVELOPMENT_SKILL = SkillModel(
 SECURITY_SKILL = SkillModel(
     'Security', 3, parents=(PROGRAMMING_SKILL, SOFTWARE_ARCHITECTURE_SKILL),
     experience=SkillExperience('8/1/2016', hours_per_week=2),
-    priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4})
+    priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5})
 )
 WEB_DEVELOPMENT_SKILL = SkillModel(
     'Web Development',
     4,
     parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL, REMOTE_DEVELOPMENT_SKILL, SECURITY_SKILL),
     primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('8/1/2016', hours_per_week=10),
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=10, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
+    ]),
     priority=SkillFocusPriority(4, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 5})
 )
+MOBILE_DEVELOPMENT_SKILL = SkillModel(
+    "Mobile Development",
+    3,
+    parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL, REMOTE_DEVELOPMENT_SKILL, SECURITY_SKILL),
+    primary_category=PROGRAMMING_SKILL,
+    experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
+    priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
+)
 CSS_SKILL = SkillModel(
     'CSS', 4, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL), flexible_case=False, primary_category=PRESENTATION_SKILL,
     experience=SkillExperience('8/1/2016', hours_per_week=1),
@@ -110,7 +138,10 @@ DEBUGGING_SKILL = SkillModel(
 )
 TESTING_SKILL = SkillModel(
     'Automated testing', 4, parents=(PROGRAMMING_SKILL,),
-    experience=SkillExperience('1/1/2018', hours_per_week=2),
+    experience=SkillExperiences([
+        SkillExperience('1/1/2018', hours_per_week=2, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=10),
+    ]),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 PARALLELISM_SKILL = SkillModel(
@@ -132,7 +163,10 @@ CRYPTOGRAPHY_SKILL = SkillModel(
 )
 ASYNC_SKILL = SkillModel(
     'Asynchronous Programming', 4, parents=(PROGRAMMING_SKILL,),
-    experience=SkillExperience('6/1/2017', hours_per_week=1.5),
+    experience=SkillExperiences([
+        SkillExperience('6/1/2017', hours_per_week=1.5, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5)
+    ]),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 DISTRIBUTED_SKILL = SkillModel(
@@ -151,18 +185,24 @@ AUTOMATION_SKILL = SkillModel(
 )
 SERVER_ADMIN_SKILL = SkillModel(
     'server administration', 4, parents=(DEV_OPS_SKILL, WEB_DEVELOPMENT_SKILL),
-    experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+    ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
 )
 NETWORKING_SKILL = SkillModel(
     'networking', 3, parents=(DEV_OPS_SKILL,),
-    experience=SkillExperience('8/1/2016', hours_per_week=0.25),
-    priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
+    ]),
+    priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 3})
 )
 MONITORING_SKILL = SkillModel(
     'application monitoring', 2, parents=(DEV_OPS_SKILL,),
     experience=SkillExperience('8/1/2016', hours_per_week=0.25),
-    priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
+    priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 3})
 )
 CI_SKILL = SkillModel(
     'CI/CD', 4, parents=(DEV_OPS_SKILL,), flexible_case=False,
@@ -171,12 +211,15 @@ CI_SKILL = SkillModel(
 )
 SEO_SKILL = SkillModel(
     'SEO', 2, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('1/1/2018', hours_per_week=0.5),
+    experience=SkillExperience('1/1/2018', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4})
 )
 CMS_SKILL = SkillModel(
     'CMS', 4, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('1/1/2018', hours_per_week=0.5),
+    experience=SkillExperiences([
+        SkillExperience('1/1/2018', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
+    ]),
     priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 2})
 )
 MIGRATIONS_SKILL = SkillModel(
@@ -186,21 +229,36 @@ MIGRATIONS_SKILL = SkillModel(
 )
 IDE_SKILL = SkillModel(
     'IDEs', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False,
-    experience=SkillExperience('1/1/2016', hours_per_week=20),
+    experience=SkillExperiences([
+        SkillExperience('1/1/2016', hours_per_week=20, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=35),
+    ]),
     priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
 )
 
 
 LINUX_SKILL = SkillModel(
     'Linux', 4, parents=(OS_SKILL,), flexible_case=False, primary_category=OTHER,
-    experience=SkillExperience('1/1/2004', hours_per_week=20),
+    experience=SkillExperiences([
+        SkillExperience('1/1/2004', hours_per_week=20, end_date_inp='1/1/2008'),
+        SkillExperience('6/1/2020', hours_per_week=40, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5),
+    ]),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 3})
 )
 WINDOWS_SKILL = SkillModel(
     'Windows', 4, parents=(OS_SKILL,), flexible_case=False, primary_category=OTHER,
-    experience=SkillExperience('1/1/2000', hours_per_week=30),
+    experience=SkillExperiences([
+        SkillExperience('1/1/2000', hours_per_week=30, end_date_inp='6/1/2020'),
+        SkillExperience('6/1/2020', hours_per_week=5),
+    ]),
     priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
 )
+MAC_SKILL = SkillModel(
+    'Mac', 3, parents=(OS_SKILL,), flexible_case=False, primary_category=OTHER,
+    experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=40),
+    priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 3})
+)
 
 TYPE_SETTING_SKILL = SkillModel('Typesetting', 4, parents=(PRESENTATION_SKILL,), priority=SkillFocusPriority(2))
 WRITING_SKILL = SkillModel('Writing', 4, parents=(PRESENTATION_SKILL, SOFT_SKILLS), priority=SkillFocusPriority(2))
@@ -217,7 +275,14 @@ STATISTICS_SKILL = SkillModel(
 )
 MODELING_SKILL = SkillModel(
     'Modeling', 4, parents=(DATA_SCIENCE_SKILL,),
-    priority=SkillFocusPriority(4, {SpecificApplicationFocus.ECONOMIST: 5, SpecificApplicationFocus.DATA_SCIENCE: 5})
+    priority=SkillFocusPriority(
+        4,
+        {
+            SpecificApplicationFocus.ECONOMIST: 5,
+            SpecificApplicationFocus.DATA_SCIENCE: 5,
+            SpecificApplicationFocus.TECH_COMPANY: 5,
+        }
+    )
 )
 VERSION_CONTORL_SKILL = SkillModel(
     'Version Control', 4, parents=(PROGRAMMING_SKILL,),
@@ -305,22 +370,55 @@ PLOTTING_SKILL = SkillModel(
 
 PYTHON_SKILL = SkillModel(
     'Python', 5, parents=(PROGRAMMING_SKILL,), flexible_case=False,
-    experience=SkillExperience('3/1/2015', hours_per_week=25),
+    experience=SkillExperiences([
+        SkillExperience('3/1/2015', hours_per_week=25, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5),
+    ]),
     priority=SkillFocusPriority(5)
 )
 JS_SKILL = SkillModel(
     'JavaScript', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False,
-    experience=SkillExperience('8/1/2016', hours_per_week=4),
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
+    ]),
     priority=SkillFocusPriority(5)
 )
 TS_SKILL = SkillModel(
     'TypeScript', 4, parents=(JS_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('8/1/2016', hours_per_week=4),
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
+    ]),
     priority=SkillFocusPriority(5)
 )
+SCALA_SKILL = SkillModel(
+    "Scala", 3, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+    experience=SkillExperiences([
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=10, end_date_inp=GRAPHQL_BEGIN_DATE),
+        SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=5),
+    ]),
+    priority=SkillFocusPriority(5),
+)
+KOTLIN_SKILL = SkillModel(
+    "Kotlin", 1, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+    experience=SkillExperiences([
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5, end_date_inp=GRAPHQL_BEGIN_DATE),
+        SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=5),
+    ]),
+    priority=SkillFocusPriority(3),
+)
+JAVA_SKILL = SkillModel(
+    "Java", 1, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+    experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+    priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4}),
+)
 AWS_SKILL = SkillModel(
     'AWS', 3, parents=(DEV_OPS_SKILL, WEB_DEVELOPMENT_SKILL, REMOTE_DEVELOPMENT_SKILL), flexible_case=False,
-    experience=SkillExperience('8/1/2016', hours_per_week=1),
+    experience=SkillExperiences([
+        SkillExperience('8/1/2016', hours_per_week=1, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.2),
+    ]),
     priority=SkillFocusPriority(4, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 5})
 )
 
@@ -348,6 +446,7 @@ _SKILLS: List[SkillModel] = [
     REMOTE_DEVELOPMENT_SKILL,
     SECURITY_SKILL,
     WEB_DEVELOPMENT_SKILL,
+    MOBILE_DEVELOPMENT_SKILL,
     CSS_SKILL,
     FRAMEWORK_SKILL,
     DEBUGGING_SKILL,
@@ -364,6 +463,7 @@ _SKILLS: List[SkillModel] = [
     CI_SKILL,
     LINUX_SKILL,
     WINDOWS_SKILL,
+    MAC_SKILL,
     PRESENTATION_SKILL,
     TYPE_SETTING_SKILL,
     COMMUNICATION_SKILL,
@@ -394,6 +494,9 @@ _SKILLS: List[SkillModel] = [
     PYTHON_SKILL,
     JS_SKILL,
     TS_SKILL,
+    SCALA_SKILL,
+    KOTLIN_SKILL,
+    JAVA_SKILL,
     AWS_SKILL,
     SEO_SKILL,
     CMS_SKILL,
@@ -413,7 +516,7 @@ _SKILLS: List[SkillModel] = [
         priority=SkillFocusPriority(
             2,
             {
-                SpecificApplicationFocus.TECH_COMPANY: 4,
+                SpecificApplicationFocus.TECH_COMPANY: 5,
                 SpecificApplicationFocus.DATA_SCIENCE: 3,
                 SpecificApplicationFocus.ECONOMIST: 3
             }
@@ -421,24 +524,58 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=3),
+        experience=SkillExperience('8/1/2016', hours_per_week=3, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(4, {SpecificApplicationFocus.TECH_COMPANY: 5})
     ),
     SkillModel(
         'Compodoc', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.1),
+        experience=SkillExperience('8/1/2016', hours_per_week=0.1, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
     ),
     SkillModel(
-        'React', 1, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
-        experience=SkillExperience('5/14/2020', hours_per_week=0, one_time_hours=20),
+        'React', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperiences([
+            SkillExperience('5/14/2020', one_time_hours=30, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=10),
+        ]),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
     ),
+    SkillModel(
+        'React Native', 4, parents=(FRAMEWORK_SKILL, TS_SKILL, MOBILE_DEVELOPMENT_SKILL, FRONTEND_SKILL),
+        flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
+        priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
+    ),
+    SkillModel(
+        'Storybook', 2, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperience('2/1/2021', one_time_hours=10),
+        priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
+    ),
     SkillModel(
         'Svelte', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
         experience=SkillExperience('1/15/2021', hours_per_week=0, one_time_hours=40),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
     ),
+    SkillModel(
+        'Webpack', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience('10/1/2020', hours_per_week=0.1),
+        priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4})
+    ),
+    SkillModel(
+        'Babel', 2, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience('10/1/2020', hours_per_week=0.01),
+        priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
+    ),
+    SkillModel(
+        'Jest', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5),
+        priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
+    ),
+    SkillModel(
+        'Qt', 2, parents=(FRAMEWORK_SKILL, FRONTEND_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience('2/12/2021', hours_per_week=0, one_time_hours=10),
+        priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
+    ),
     SkillModel(
         'Docker', 4, parents=(DEV_OPS_SKILL,), flexible_case=False,
         experience=SkillExperience('8/1/2016', hours_per_week=2),
@@ -488,59 +625,92 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel(
         'EC2', 4, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'RDS', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'VPC', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'Route53', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.1),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.1, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.01),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'S3', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'ElastiCache', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.1),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'IAM', 3, parents=(AWS_SKILL, COLLABORATION_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.01),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'CloudWatch', 3, parents=(AWS_SKILL, MONITORING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'CloudFormation', 2, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False,
         primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.15),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=0.15, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'ECS', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('6/1/2020', hours_per_week=0.25, one_time_hours=20),
+        experience=SkillExperiences([
+            SkillExperience('6/1/2020', hours_per_week=0.25, one_time_hours=20, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
         'CDK', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False,
         primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('6/1/2020', hours_per_week=0.1, one_time_hours=30),
+        experience=SkillExperiences([
+            SkillExperience('6/1/2020', hours_per_week=0.1, one_time_hours=30, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.02),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
 
@@ -552,13 +722,16 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel(
         'JIRA', 4, parents=(WEB_DEVELOPMENT_SKILL, COLLABORATION_SKILL), flexible_case=False, primary_category=OTHER,
-        experience=SkillExperience('8/1/2016', hours_per_week=2),
+        experience=SkillExperience('8/1/2016', hours_per_week=2, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
 
     SkillModel(
         'PyCharm', 4, parents=(IDE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-        experience=SkillExperience('1/1/2016', hours_per_week=20),
+        experience=SkillExperiences([
+            SkillExperience('1/1/2016', hours_per_week=20, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5),
+        ]),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 2})
     ),
     SkillModel(
@@ -566,17 +739,26 @@ _SKILLS: List[SkillModel] = [
         experience=SkillExperience('1/1/2019', hours_per_week=10),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 2})
     ),
+    SkillModel(
+        'IDEA', 4, parents=(IDE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+        experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=25),
+        priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 2})
+    ),
 
     SkillModel(
         'empirical research', 5, parents=(RESEARCH_SKILL, STATISTICS_SKILL, DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL),
         primary_category=DATA_SCIENCE_SKILL,
-        experience=SkillExperience('4/1/2012', hours_per_week=20),
+        experience=SkillExperiences([
+            SkillExperience('4/1/2012', hours_per_week=20, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5),
+        ]),
         priority=SkillFocusPriority(
             4,
             {
                 SpecificApplicationFocus.DATA_SCIENCE: 5,
                 SpecificApplicationFocus.ECONOMIST: 5,
-                SpecificApplicationFocus.ASSET_MANAGER: 5
+                SpecificApplicationFocus.ASSET_MANAGER: 5,
+                SpecificApplicationFocus.TECH_COMPANY: 5,
             }
         )
     ),
@@ -588,7 +770,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Gitlab CI', 3, parents=(CI_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.5, one_time_hours=75),
+        experience=SkillExperience('8/1/2016', hours_per_week=0.5, one_time_hours=75, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
     ),
 
@@ -637,6 +819,7 @@ _SKILLS: List[SkillModel] = [
             {
                 SpecificApplicationFocus.DATA_SCIENCE: 5,
                 SpecificApplicationFocus.ECONOMIST: 5,
+                SpecificApplicationFocus.TECH_COMPANY: 5,
             }
         )
     ),
@@ -657,13 +840,25 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'Sass', 3, parents=(CSS_SKILL,), flexible_case=False, primary_category=FRAMEWORK_SKILL,
         experience=SkillExperience('6/1/2020', hours_per_week=1),
-        priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
+        priority=SkillFocusPriority(
+            2,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 5,
+                SpecificApplicationFocus.DATA_SCIENCE: 3
+            }
+        )
     ),
     SkillModel(
         'Bootstrap', 3, parents=(CSS_SKILL, JS_SKILL, FRAMEWORK_SKILL), flexible_case=False,
         primary_category=FRAMEWORK_SKILL,
         experience=SkillExperience('6/1/2020', hours_per_week=0.2, one_time_hours=60),
-        priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
+        priority=SkillFocusPriority(
+            2,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 5,
+                SpecificApplicationFocus.DATA_SCIENCE: 3
+            }
+        )
     ),
     SkillModel(
         'Material Design', 2, parents=(CSS_SKILL, JS_SKILL, FRAMEWORK_SKILL), flexible_case=False,
@@ -673,13 +868,16 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'jQuery', 2, parents=(JS_SKILL, FRAMEWORK_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.1),
+        experience=SkillExperience('8/1/2016', one_time_hours=25),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
 
     SkillModel(
         'pandas', 5, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL), flexible_case=False,
-        experience=SkillExperience('5/1/2015', hours_per_week=5),
+        experience=SkillExperiences([
+            SkillExperience('5/1/2015', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=1),
+        ]),
         priority=SkillFocusPriority(
             4,
             {
@@ -691,7 +889,10 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'NumPy', 4, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL), flexible_case=False,
-        experience=SkillExperience('5/1/2015', hours_per_week=1),
+        experience=SkillExperiences([
+            SkillExperience('5/1/2015', hours_per_week=1, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.25),
+        ]),
         priority=SkillFocusPriority(
             4,
             {
@@ -703,11 +904,14 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'SciPy', 3, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL,), flexible_case=False,
-        experience=SkillExperience('5/1/2015', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience('5/1/2015', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
+        ]),
         priority=SkillFocusPriority(
             4,
             {
-                SpecificApplicationFocus.TECH_COMPANY: 5,
+                SpecificApplicationFocus.TECH_COMPANY: 4,
                 SpecificApplicationFocus.DATA_SCIENCE: 5,
                 SpecificApplicationFocus.ECONOMIST: 5
             }
@@ -732,7 +936,7 @@ _SKILLS: List[SkillModel] = [
         priority=SkillFocusPriority(
             3,
             {
-                SpecificApplicationFocus.TECH_COMPANY: 4,
+                SpecificApplicationFocus.TECH_COMPANY: 5,
                 SpecificApplicationFocus.DATA_SCIENCE: 5,
                 SpecificApplicationFocus.ECONOMIST: 5
             }
@@ -827,7 +1031,7 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel(
         'Flask', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=5),
+        experience=SkillExperience('8/1/2016', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(
             4,
             {
@@ -851,7 +1055,10 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'SQLAlchemy', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=5),
+        experience=SkillExperiences([
+            SkillExperience('8/1/2016', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+        ]),
         priority=SkillFocusPriority(
             4,
             {
@@ -861,9 +1068,25 @@ _SKILLS: List[SkillModel] = [
             }
         )
     ),
+    SkillModel(
+        'pydantic', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperiences([
+            SkillExperience('6/1/2019', hours_per_week=1, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+        ]),
+        priority=SkillFocusPriority(
+            2,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 3,
+            }
+        )
+    ),
     SkillModel(
         'FastAPI', 3, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('6/1/2020', hours_per_week=3, one_time_hours=30),
+        experience=SkillExperiences([
+            SkillExperience('6/1/2020', hours_per_week=3, one_time_hours=30, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+        ]),
         priority=SkillFocusPriority(
             3,
             {
@@ -872,10 +1095,23 @@ _SKILLS: List[SkillModel] = [
             }
         )
     ),
-
+    SkillModel(
+        'GraphQL', 3, parents=BE_WEB_FRAMEWORK_SKILLS + FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=10),
+        priority=SkillFocusPriority(
+            2,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 5,
+                SpecificApplicationFocus.DATA_SCIENCE: 3,
+            }
+        )
+    ),
     SkillModel(
         'Celery', 4, parents=ASYNC_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('1/1/2018', hours_per_week=2),
+        experience=SkillExperiences([
+            SkillExperience('1/1/2018', hours_per_week=2, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.2),
+        ]),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
     ),
     SkillModel(
@@ -928,7 +1164,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Wagtail', 2, parents=FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS + (CMS_SKILL,), flexible_case=False,
-        experience=SkillExperience('1/1/2018', hours_per_week=0.2),
+        experience=SkillExperience('1/1/2018', hours_per_week=0.2, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
     ),
 
@@ -961,7 +1197,12 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'fire', 3, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, CLI_SKILL), flexible_case=False,
-        experience=SkillExperience('1/1/2018', hours_per_week=0.1),
+        experience=SkillExperience('1/1/2018', hours_per_week=0.1, end_date_inp='1/1/2020'),
+        priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
+    ),
+    SkillModel(
+        'typer', 3, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, CLI_SKILL), flexible_case=False,
+        experience=SkillExperience('1/1/2020', hours_per_week=0.1),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
     ),
 
