@@ -66,7 +66,10 @@ def _add_generated_data_to_project_report(report: ProjectReport):
     url = report.data.get('github_url')
     package_directory = report.data.get('package_directory')
     if url is not None:
-        report.data['docs_url'] = f'https://nickderobertis.github.io/{title}/'
+        docs_url = f'https://nickderobertis.github.io/{title}/'
+        response = requests.get(docs_url)
+        if response.status_code == 200:
+            report.data['docs_url'] = docs_url
     if package_directory is not None:
         potential_logo_url = f'https://nickderobertis.github.io/derobertis-project-logo/_images/{package_directory}.svg'
         response = requests.get(potential_logo_url)
